@@ -8,7 +8,7 @@ import coloredlogs
 import sys
 
 FIELD_STYLES = dict(
-    levelname=dict(color='green', bold=coloredlogs.CAN_USE_BOLD_FONT),
+    levelname=dict(color='green'),
 )
 
 def setup_logger(name):
